# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid *.list files interfering with signature test
%global debug_package %{nil}

# Similarly for .package_note* files
%undefine _package_note_file

# Store keys in a temp directory
%global gnupghome %(mktemp --directory)

Summary:	Expand template text with embedded perl
Name:		perl-Text-Template
Version:	1.61
Release:	2.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Text-Template
Source0:	https://cpan.metacpan.org/modules/by-module/Text/Text-Template-%{version}.tar.gz
Source1:	B954CD8E.asc
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gnupg2
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(warnings)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
# Test Suite
BuildRequires:	perl(Config)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(lib)
BuildRequires:	perl(Safe)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::More::UTF8)
BuildRequires:	perl(Test::Warnings)
BuildRequires:	perl(utf8)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Author Tests
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Signature)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Carp)
Requires:	perl(Encode)

%description
Text::Template is a library for generating form letters, building HTML pages,
or filling in templates generally.  A `template' is a piece of text that
has little Perl programs embedded in it here and there.  When you
`fill in' a template, you evaluate the little programs and replace
them with their values.

%prep
%setup -q -n Text-Template-%{version}

# Create a GPG directory for testing, to avoid using ~/.gnupg
export GNUPGHOME=%{gnupghome}
gpg2 --import %{SOURCE1}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
export GNUPGHOME=%{gnupghome}
make test AUTHOR_TESTING=1

%clean
rm -rf %{buildroot} %{gnupghome}

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Text/
%{_mandir}/man3/Text::Template.3*
%{_mandir}/man3/Text::Template::Preprocess.3*

%changelog
* Sun Jun 25 2023 Paul Howarth <paul@city-fan.org> - 1.61-2
- Use SPDX-format license tag

* Fri Apr 29 2022 Paul Howarth <paul@city-fan.org> - 1.61-1
- Update to 1.61
  - Skip taint tests if perl was compiled with taint disabled (GH#20)

* Fri Mar 18 2022 Paul Howarth <paul@city-fan.org> - 1.60-2
- Work around package note files breaking t/author-signature.t

* Sun Sep  5 2021 Paul Howarth <paul@city-fan.org> - 1.60-1
- Update to 1.60
  - Fix another POD syntax error
- Fix dist tags for Alma and Rocky Linux
- Use %%license unconditionally

* Fri Jul  3 2020 Paul Howarth <paul@city-fan.org> - 1.59-1
- Update to 1.59
  - Fix syntax error in POD example code

* Sun Oct  6 2019 Paul Howarth <paul@city-fan.org> - 1.58-1
- Update to 1.58 (no changes)

* Mon Sep  9 2019 Paul Howarth <paul@city-fan.org> - 1.57-1
- Update to 1.57
  - Remove hard coded (old) version number from README

* Wed Jul 10 2019 Paul Howarth <paul@city-fan.org> - 1.56-1
- Update to 1.56
  - Fix typos in Changes file
- Remove %%{gnupghome} in %%clean section, not %%check section

* Tue Feb 26 2019 Paul Howarth <paul@city-fan.org> - 1.55-1
- Update to 1.55
  - Improve AppVeyor tests for older Perls
  - Check for Test::More 0.94 and skip tests if not installed where
    done_testing() is used
  - Improve workaround for broken Win32 File::Temp taint failure
  - Skip/todo tests that fail under Devel::Cover
  - Add checks and skip_all checks for non-core test modules

* Mon Jan 14 2019 Paul Howarth <paul@city-fan.org> - 1.54-1
- Update to 1.54
  - Fix tempfile creation during tests on Win32
- Switch upstream from search.cpan.org to metacpan.org

* Thu May  3 2018 Paul Howarth <paul@city-fan.org> - 1.53-1
- Update to 1.53
  - Add support for decoding template files via ENCODING constructor arg (GH#11)
  - Docs clean-up: Replace indirect-object style examples and use class method
    style constructor calls in the POD docs
  - Docs clean-up: Remove hard tabs from POD, replace dated, unfair synopsis
    (GH#5), convert "THANKS" section to a POD list

* Tue Mar 20 2018 Paul Howarth <paul@city-fan.org> - 1.52-1
- Update to 1.52
  - Fix possible 'Subroutine ... redefined' warning (GH#10)

* Wed Mar  7 2018 Paul Howarth <paul@city-fan.org> - 1.51-1
- Update to 1.51
  - Add test for nested tags breakage that happened in v1.46
  - Turn off strict+warnings in sections where template code is eval'ed (GH#9)

* Mon Feb 12 2018 Paul Howarth <paul@city-fan.org> - 1.50-1
- Update to 1.50
  - Revert support for identical start/end delimiters (e.g. @@foo@@, XXfooXX)
    due to breakage with nested tags (GH#8); will revisit this in a future
    release

* Thu Feb  8 2018 Paul Howarth <paul@city-fan.org> - 1.49-1
- Update to 1.49
  - Remove COPYING and Artistic files from the dist; these are replaced by the
    Dist::Zilla generated LICENSE file
  - Use strict/warnings
  - Remove $VERSION checks from tests, which makes it easier to run the test
    with Dist::Zilla and avoids maintenance issue of updating the tests for
    each release
  - Allow precompiled templates to work with preprocessing (CPAN RT#29928)
  - Add "strict" option to fill_in(); this adds "use strict" and
    "use vars (...)" to the prepend section, and only the keys of the HASH
    option are allowed in the template (CPAN RT#55696)
  - Fix templates with inline comments without newline after comment for
    Perl < 5.18 (CPAN RT#34292)
  - Don't use bareword file handles
  - Use three arg form of open()
  - Fix BROKEN behaviour so that it returns the text accumulated so far on
    undef as documented (CPAN RT#28974)
  - Source code clean-ups
  - Minimum Perl version is now 5.8.0
  - Allow start/end delimiters to be identical (e.g.: @@foo@@, XXfooXX)
    (CPAN RT#46639)
  - Fix and document the FILENAME parameter to fill_in() (CPAN RT#106093)
  - Test suite clean-ups:
    - Turn on strict/warnings for all tests
    - Run tests through perltidy and formatting cleanup
    - Remove number prefixes from test names
    - Use Test::More instead of generating TAP by hand
    - Use three-arg form of open()
    - Don't use indirect object syntax
    - Don't use bareword file handles
    - Use File::Temp to generate temporary files
- Enable signature test
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Feb 28 2017 Paul Howarth <paul@city-fan.org> - 1.47-1
- Update to 1.47
  - Fix longstanding memory leak in _scrubpkg() (CPAN RT#22031)
  - Fix various spelling errors (CPAN RT#86872)
- This release by MSCHOUT → update source URL
- License reverted to (GPL+ or Artistic)

* Thu Oct 13 2016 Paul Howarth <paul@city-fan.org> - 1.46-5
- Classify buildreqs by usage
- Correct license declaration to ((GPL+ or Artistic) and (GPLv2+ or Artistic))
  (#1198991)
- Use %%license where possible
- Drop %%defattr, redundant since rpm 4.4
- Simplify find command using -delete

* Mon Feb 11 2013 Paul Howarth <paul@city-fan.org> - 1.46-1
- Update to 1.46
  - New method Text::Template->append_text_to_output, which Text::Template
    always uses whenever it wants to emit output; you can subclass this to get
    control over the output, for example for postprocessing
  - A spurious warning is no longer emitted when the TYPE parameter to ->new
    is omitted

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 1.45-10
- BR: perl(Exporter), perl(lib) and perl(Safe)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 1.45-8
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.45-6
- Rebuild for perl 5.12.1 in Rawhide

* Tue May 11 2010 Paul Howarth <paul@city-fan.org> - 1.45-5
- Fix dist tag for RHEL-6 Beta

* Fri Mar  5 2010 Paul Howarth <paul@city-fan.org> - 1.45-4
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Thu Oct  1 2009 Paul Howarth <paul@city-fan.org> - 1.45-3
- Define RPM macros in global scope

* Fri Nov 14 2008 Paul Howarth <paul@city-fan.org> - 1.45-2
- Tweak dist tag macros to work on current Rawhide with three-part releasenum

* Mon Apr 21 2008 Paul Howarth <paul@city-fan.org> - 1.45-1
- Update to 1.45
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Tue Mar 20 2007 Paul Howarth <paul@city-fan.org> - 1.44-4
- BuildRequire perl(ExtUtils::MakeMaker)
- Fix dist tag for development builds and Fedora 7 onwards
- Don't use macros in command paths, hardcode them instead
- Fix argument order for find with -depth
- Remove buildroot unconditionally in %%clean and %%install
- Use search.cpan.org URLs
- Remove %%{__perl_version} macro, used only once
- Remove %%{__perl_package} macro, used only twice
- Define %%{__id_u} in a more portable way

* Fri Sep  2 2005 Paul Howarth <paul@city-fan.org> - 1.44-3
- Remove redundant arch-specific stuff
- Add note about package being available in Fedora Extras
- Fix directory ownership issues

* Wed May 25 2005 Paul Howarth <paul@city-fan.org> - 1.44-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Mon May 10 2004 Paul Howarth <paul@city-fan.org> - 1.44-1
- Initial build
